// generated from rosidl_generator_c/resource/idl__description.c.em
// with input from example_interfaces:action/Fibonacci.idl
// generated code does not contain a copyright notice

#include "example_interfaces/action/detail/fibonacci__functions.h"

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci__get_type_hash(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x95, 0x08, 0x05, 0x1d, 0xa1, 0xea, 0x46, 0x58,
      0xde, 0x14, 0x4b, 0x09, 0xbd, 0x06, 0x90, 0xff,
      0x3d, 0xe5, 0x21, 0x04, 0x68, 0x3d, 0x84, 0x7a,
      0xed, 0x76, 0x4d, 0x29, 0x15, 0x90, 0x6f, 0x51,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_Goal__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x22, 0x6c, 0xb4, 0x37, 0xe4, 0x35, 0x5d, 0xcd,
      0x3e, 0x91, 0x4f, 0x93, 0x03, 0x82, 0xa3, 0xb0,
      0xcc, 0x1d, 0xa8, 0x15, 0x45, 0xbd, 0x31, 0x9e,
      0xd5, 0x54, 0xe9, 0x5a, 0x03, 0x25, 0x5f, 0x51,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_Result__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xfe, 0xa8, 0x13, 0x94, 0xf2, 0x5a, 0xa4, 0x50,
      0x22, 0x17, 0x95, 0x3f, 0x1a, 0x02, 0x1f, 0xb7,
      0x50, 0xe7, 0x9c, 0x10, 0xbb, 0xd4, 0x3f, 0x13,
      0xdd, 0x94, 0x63, 0x2d, 0xa6, 0x56, 0x96, 0x49,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_Feedback__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x2b, 0x12, 0xe3, 0x73, 0x61, 0xda, 0x6f, 0x40,
      0x8d, 0x4c, 0x85, 0xbc, 0x24, 0xa1, 0x8d, 0xe6,
      0x43, 0x33, 0xf2, 0x90, 0x82, 0xf2, 0xca, 0x34,
      0xb5, 0xee, 0x33, 0xdc, 0x4c, 0x8b, 0x42, 0xa9,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_SendGoal__get_type_hash(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xd1, 0xa5, 0x7f, 0xb2, 0xa4, 0xaf, 0xe8, 0xc2,
      0x1e, 0x34, 0xfb, 0x10, 0xdb, 0x20, 0x6f, 0x16,
      0xce, 0x67, 0x29, 0xb2, 0x85, 0x31, 0x14, 0x14,
      0x72, 0xdf, 0x92, 0x27, 0x7c, 0x55, 0xb5, 0x57,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_SendGoal_Request__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x3d, 0x08, 0x89, 0x42, 0xb4, 0x13, 0x24, 0x7d,
      0xb5, 0x36, 0x57, 0x6f, 0x02, 0x86, 0x76, 0x8c,
      0x6b, 0xe8, 0xfc, 0xd5, 0xd0, 0xc9, 0xa5, 0xd5,
      0x44, 0xf3, 0x59, 0xfb, 0xa0, 0x90, 0xa2, 0x38,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_SendGoal_Response__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xd8, 0xc0, 0x7b, 0xb3, 0xd5, 0xb7, 0x66, 0xfe,
      0x4b, 0x43, 0x15, 0x9c, 0x9a, 0x52, 0x22, 0xaf,
      0x52, 0x14, 0xe2, 0xfc, 0xc2, 0x92, 0x29, 0xb9,
      0x91, 0xd8, 0x26, 0x16, 0x6c, 0x51, 0x2b, 0xe1,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_SendGoal_Event__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xd5, 0xe5, 0xb3, 0x12, 0xdb, 0xf8, 0x47, 0x30,
      0x7b, 0x0e, 0x87, 0x6c, 0x2e, 0xcc, 0x9d, 0x80,
      0x25, 0x8e, 0x95, 0xb0, 0xd1, 0x7f, 0x8f, 0x7b,
      0xfc, 0x58, 0x1c, 0x4a, 0x29, 0xc8, 0x34, 0x84,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_GetResult__get_type_hash(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x1b, 0x0d, 0xe0, 0xd5, 0xd2, 0x9d, 0xc9, 0x55,
      0xd9, 0x2f, 0x54, 0x67, 0x06, 0x56, 0x84, 0x28,
      0x63, 0x27, 0x71, 0xdb, 0x13, 0xec, 0x84, 0xc1,
      0x5e, 0xc1, 0xc1, 0xa5, 0x9f, 0x42, 0x4a, 0x57,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_GetResult_Request__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xc8, 0xa4, 0xf5, 0xe7, 0xd1, 0x3b, 0x81, 0x28,
      0x6e, 0xe1, 0x04, 0x3e, 0x2e, 0xcd, 0x08, 0x42,
      0x81, 0xce, 0xcf, 0x1f, 0xf0, 0x6a, 0xaa, 0x79,
      0x94, 0x64, 0xf5, 0xf1, 0x54, 0x79, 0xf0, 0x03,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_GetResult_Response__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x60, 0x21, 0xdc, 0x98, 0xab, 0x9b, 0x4b, 0xbe,
      0x39, 0x5e, 0x48, 0xaa, 0x4d, 0xe8, 0x1e, 0xe5,
      0xf6, 0x8e, 0xb5, 0x70, 0xf8, 0x83, 0x58, 0xaf,
      0xfc, 0xc6, 0x48, 0x14, 0x66, 0x68, 0xb2, 0x4f,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_GetResult_Event__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xac, 0x4e, 0x9c, 0xdb, 0x95, 0x4c, 0x2e, 0x19,
      0x2c, 0x9f, 0x07, 0x53, 0xd4, 0x6f, 0x59, 0xab,
      0x6f, 0x01, 0x01, 0xd5, 0xfb, 0x5b, 0x95, 0x42,
      0xfd, 0x8a, 0xb2, 0x90, 0x6e, 0x40, 0xc4, 0xd9,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_example_interfaces
const rosidl_type_hash_t *
example_interfaces__action__Fibonacci_FeedbackMessage__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xc1, 0xde, 0x71, 0xaf, 0xd5, 0x2e, 0x49, 0xa8,
      0x9c, 0x53, 0xd8, 0x26, 0x23, 0x66, 0x88, 0x41,
      0x85, 0xbc, 0x0a, 0x02, 0xf7, 0x8c, 0xe0, 0x51,
      0xc4, 0xe4, 0x6b, 0x0a, 0x7f, 0xe5, 0x9b, 0xb2,
    }};
  return &hash;
}

#include <assert.h>
#include <string.h>

// Include directives for referenced types
#include "service_msgs/msg/detail/service_event_info__functions.h"
#include "unique_identifier_msgs/msg/detail/uuid__functions.h"
#include "builtin_interfaces/msg/detail/time__functions.h"

// Hashes for external referenced types
#ifndef NDEBUG
static const rosidl_type_hash_t builtin_interfaces__msg__Time__EXPECTED_HASH = {1, {
    0xb1, 0x06, 0x23, 0x5e, 0x25, 0xa4, 0xc5, 0xed,
    0x35, 0x09, 0x8a, 0xa0, 0xa6, 0x1a, 0x3e, 0xe9,
    0xc9, 0xb1, 0x8d, 0x19, 0x7f, 0x39, 0x8b, 0x0e,
    0x42, 0x06, 0xce, 0xa9, 0xac, 0xf9, 0xc1, 0x97,
  }};
static const rosidl_type_hash_t service_msgs__msg__ServiceEventInfo__EXPECTED_HASH = {1, {
    0x41, 0xbc, 0xbb, 0xe0, 0x7a, 0x75, 0xc9, 0xb5,
    0x2b, 0xc9, 0x6b, 0xfd, 0x5c, 0x24, 0xd7, 0xf0,
    0xfc, 0x0a, 0x08, 0xc0, 0xcb, 0x79, 0x21, 0xb3,
    0x37, 0x3c, 0x57, 0x32, 0x34, 0x5a, 0x6f, 0x45,
  }};
static const rosidl_type_hash_t unique_identifier_msgs__msg__UUID__EXPECTED_HASH = {1, {
    0x1b, 0x8e, 0x8a, 0xca, 0x95, 0x8c, 0xbe, 0xa2,
    0x8f, 0xe6, 0xef, 0x60, 0xbf, 0x6c, 0x19, 0xb6,
    0x83, 0xc9, 0x7a, 0x9e, 0xf6, 0x0b, 0xb3, 0x47,
    0x52, 0x06, 0x7d, 0x0f, 0x2f, 0x7a, 0xb4, 0x37,
  }};
#endif

static char example_interfaces__action__Fibonacci__TYPE_NAME[] = "example_interfaces/action/Fibonacci";
static char builtin_interfaces__msg__Time__TYPE_NAME[] = "builtin_interfaces/msg/Time";
static char example_interfaces__action__Fibonacci_Feedback__TYPE_NAME[] = "example_interfaces/action/Fibonacci_Feedback";
static char example_interfaces__action__Fibonacci_FeedbackMessage__TYPE_NAME[] = "example_interfaces/action/Fibonacci_FeedbackMessage";
static char example_interfaces__action__Fibonacci_GetResult__TYPE_NAME[] = "example_interfaces/action/Fibonacci_GetResult";
static char example_interfaces__action__Fibonacci_GetResult_Event__TYPE_NAME[] = "example_interfaces/action/Fibonacci_GetResult_Event";
static char example_interfaces__action__Fibonacci_GetResult_Request__TYPE_NAME[] = "example_interfaces/action/Fibonacci_GetResult_Request";
static char example_interfaces__action__Fibonacci_GetResult_Response__TYPE_NAME[] = "example_interfaces/action/Fibonacci_GetResult_Response";
static char example_interfaces__action__Fibonacci_Goal__TYPE_NAME[] = "example_interfaces/action/Fibonacci_Goal";
static char example_interfaces__action__Fibonacci_Result__TYPE_NAME[] = "example_interfaces/action/Fibonacci_Result";
static char example_interfaces__action__Fibonacci_SendGoal__TYPE_NAME[] = "example_interfaces/action/Fibonacci_SendGoal";
static char example_interfaces__action__Fibonacci_SendGoal_Event__TYPE_NAME[] = "example_interfaces/action/Fibonacci_SendGoal_Event";
static char example_interfaces__action__Fibonacci_SendGoal_Request__TYPE_NAME[] = "example_interfaces/action/Fibonacci_SendGoal_Request";
static char example_interfaces__action__Fibonacci_SendGoal_Response__TYPE_NAME[] = "example_interfaces/action/Fibonacci_SendGoal_Response";
static char service_msgs__msg__ServiceEventInfo__TYPE_NAME[] = "service_msgs/msg/ServiceEventInfo";
static char unique_identifier_msgs__msg__UUID__TYPE_NAME[] = "unique_identifier_msgs/msg/UUID";

// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci__FIELD_NAME__goal[] = "goal";
static char example_interfaces__action__Fibonacci__FIELD_NAME__result[] = "result";
static char example_interfaces__action__Fibonacci__FIELD_NAME__feedback[] = "feedback";
static char example_interfaces__action__Fibonacci__FIELD_NAME__send_goal_service[] = "send_goal_service";
static char example_interfaces__action__Fibonacci__FIELD_NAME__get_result_service[] = "get_result_service";
static char example_interfaces__action__Fibonacci__FIELD_NAME__feedback_message[] = "feedback_message";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci__FIELD_NAME__goal, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_Goal__TYPE_NAME, 40, 40},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci__FIELD_NAME__result, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_Result__TYPE_NAME, 42, 42},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci__FIELD_NAME__feedback, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_Feedback__TYPE_NAME, 44, 44},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci__FIELD_NAME__send_goal_service, 17, 17},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_SendGoal__TYPE_NAME, 44, 44},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci__FIELD_NAME__get_result_service, 18, 18},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_GetResult__TYPE_NAME, 45, 45},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci__FIELD_NAME__feedback_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_FeedbackMessage__TYPE_NAME, 51, 51},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_Feedback__TYPE_NAME, 44, 44},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_FeedbackMessage__TYPE_NAME, 51, 51},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult__TYPE_NAME, 45, 45},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Event__TYPE_NAME, 51, 51},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Request__TYPE_NAME, 53, 53},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Response__TYPE_NAME, 54, 54},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_Goal__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_Result__TYPE_NAME, 42, 42},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal__TYPE_NAME, 44, 44},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Event__TYPE_NAME, 50, 50},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Request__TYPE_NAME, 52, 52},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Response__TYPE_NAME, 53, 53},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci__get_type_description(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci__TYPE_NAME, 35, 35},
      {example_interfaces__action__Fibonacci__FIELDS, 6, 6},
    },
    {example_interfaces__action__Fibonacci__REFERENCED_TYPE_DESCRIPTIONS, 15, 15},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = example_interfaces__action__Fibonacci_Feedback__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = example_interfaces__action__Fibonacci_FeedbackMessage__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = example_interfaces__action__Fibonacci_GetResult__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = example_interfaces__action__Fibonacci_GetResult_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[5].fields = example_interfaces__action__Fibonacci_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[6].fields = example_interfaces__action__Fibonacci_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[7].fields = example_interfaces__action__Fibonacci_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[8].fields = example_interfaces__action__Fibonacci_Result__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[9].fields = example_interfaces__action__Fibonacci_SendGoal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[10].fields = example_interfaces__action__Fibonacci_SendGoal_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[11].fields = example_interfaces__action__Fibonacci_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[12].fields = example_interfaces__action__Fibonacci_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[13].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[14].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_Goal__FIELD_NAME__order[] = "order";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_Goal__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_Goal__FIELD_NAME__order, 5, 5},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_INT32,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_Goal__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_Goal__TYPE_NAME, 40, 40},
      {example_interfaces__action__Fibonacci_Goal__FIELDS, 1, 1},
    },
    {NULL, 0, 0},
  };
  if (!constructed) {
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_Result__FIELD_NAME__sequence[] = "sequence";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_Result__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_Result__FIELD_NAME__sequence, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_INT32_UNBOUNDED_SEQUENCE,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_Result__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_Result__TYPE_NAME, 42, 42},
      {example_interfaces__action__Fibonacci_Result__FIELDS, 1, 1},
    },
    {NULL, 0, 0},
  };
  if (!constructed) {
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_Feedback__FIELD_NAME__sequence[] = "sequence";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_Feedback__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_Feedback__FIELD_NAME__sequence, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_INT32_UNBOUNDED_SEQUENCE,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_Feedback__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_Feedback__TYPE_NAME, 44, 44},
      {example_interfaces__action__Fibonacci_Feedback__FIELDS, 1, 1},
    },
    {NULL, 0, 0},
  };
  if (!constructed) {
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_SendGoal__FIELD_NAME__request_message[] = "request_message";
static char example_interfaces__action__Fibonacci_SendGoal__FIELD_NAME__response_message[] = "response_message";
static char example_interfaces__action__Fibonacci_SendGoal__FIELD_NAME__event_message[] = "event_message";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_SendGoal__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_SendGoal__FIELD_NAME__request_message, 15, 15},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_SendGoal_Request__TYPE_NAME, 52, 52},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal__FIELD_NAME__response_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_SendGoal_Response__TYPE_NAME, 53, 53},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal__FIELD_NAME__event_message, 13, 13},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_SendGoal_Event__TYPE_NAME, 50, 50},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci_SendGoal__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_Goal__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Event__TYPE_NAME, 50, 50},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Request__TYPE_NAME, 52, 52},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Response__TYPE_NAME, 53, 53},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_SendGoal__get_type_description(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_SendGoal__TYPE_NAME, 44, 44},
      {example_interfaces__action__Fibonacci_SendGoal__FIELDS, 3, 3},
    },
    {example_interfaces__action__Fibonacci_SendGoal__REFERENCED_TYPE_DESCRIPTIONS, 7, 7},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = example_interfaces__action__Fibonacci_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = example_interfaces__action__Fibonacci_SendGoal_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = example_interfaces__action__Fibonacci_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = example_interfaces__action__Fibonacci_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_SendGoal_Request__FIELD_NAME__goal_id[] = "goal_id";
static char example_interfaces__action__Fibonacci_SendGoal_Request__FIELD_NAME__goal[] = "goal";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_SendGoal_Request__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_SendGoal_Request__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Request__FIELD_NAME__goal, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_Goal__TYPE_NAME, 40, 40},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci_SendGoal_Request__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {example_interfaces__action__Fibonacci_Goal__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_SendGoal_Request__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_SendGoal_Request__TYPE_NAME, 52, 52},
      {example_interfaces__action__Fibonacci_SendGoal_Request__FIELDS, 2, 2},
    },
    {example_interfaces__action__Fibonacci_SendGoal_Request__REFERENCED_TYPE_DESCRIPTIONS, 2, 2},
  };
  if (!constructed) {
    description.referenced_type_descriptions.data[0].fields = example_interfaces__action__Fibonacci_Goal__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_SendGoal_Response__FIELD_NAME__accepted[] = "accepted";
static char example_interfaces__action__Fibonacci_SendGoal_Response__FIELD_NAME__stamp[] = "stamp";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_SendGoal_Response__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_SendGoal_Response__FIELD_NAME__accepted, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_BOOLEAN,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Response__FIELD_NAME__stamp, 5, 5},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci_SendGoal_Response__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_SendGoal_Response__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_SendGoal_Response__TYPE_NAME, 53, 53},
      {example_interfaces__action__Fibonacci_SendGoal_Response__FIELDS, 2, 2},
    },
    {example_interfaces__action__Fibonacci_SendGoal_Response__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_SendGoal_Event__FIELD_NAME__info[] = "info";
static char example_interfaces__action__Fibonacci_SendGoal_Event__FIELD_NAME__request[] = "request";
static char example_interfaces__action__Fibonacci_SendGoal_Event__FIELD_NAME__response[] = "response";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_SendGoal_Event__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_SendGoal_Event__FIELD_NAME__info, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Event__FIELD_NAME__request, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {example_interfaces__action__Fibonacci_SendGoal_Request__TYPE_NAME, 52, 52},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Event__FIELD_NAME__response, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {example_interfaces__action__Fibonacci_SendGoal_Response__TYPE_NAME, 53, 53},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci_SendGoal_Event__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_Goal__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Request__TYPE_NAME, 52, 52},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_SendGoal_Response__TYPE_NAME, 53, 53},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_SendGoal_Event__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_SendGoal_Event__TYPE_NAME, 50, 50},
      {example_interfaces__action__Fibonacci_SendGoal_Event__FIELDS, 3, 3},
    },
    {example_interfaces__action__Fibonacci_SendGoal_Event__REFERENCED_TYPE_DESCRIPTIONS, 6, 6},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = example_interfaces__action__Fibonacci_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = example_interfaces__action__Fibonacci_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = example_interfaces__action__Fibonacci_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_GetResult__FIELD_NAME__request_message[] = "request_message";
static char example_interfaces__action__Fibonacci_GetResult__FIELD_NAME__response_message[] = "response_message";
static char example_interfaces__action__Fibonacci_GetResult__FIELD_NAME__event_message[] = "event_message";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_GetResult__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_GetResult__FIELD_NAME__request_message, 15, 15},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_GetResult_Request__TYPE_NAME, 53, 53},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult__FIELD_NAME__response_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_GetResult_Response__TYPE_NAME, 54, 54},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult__FIELD_NAME__event_message, 13, 13},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_GetResult_Event__TYPE_NAME, 51, 51},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci_GetResult__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Event__TYPE_NAME, 51, 51},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Request__TYPE_NAME, 53, 53},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Response__TYPE_NAME, 54, 54},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_Result__TYPE_NAME, 42, 42},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_GetResult__get_type_description(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_GetResult__TYPE_NAME, 45, 45},
      {example_interfaces__action__Fibonacci_GetResult__FIELDS, 3, 3},
    },
    {example_interfaces__action__Fibonacci_GetResult__REFERENCED_TYPE_DESCRIPTIONS, 7, 7},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = example_interfaces__action__Fibonacci_GetResult_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = example_interfaces__action__Fibonacci_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = example_interfaces__action__Fibonacci_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = example_interfaces__action__Fibonacci_Result__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_GetResult_Request__FIELD_NAME__goal_id[] = "goal_id";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_GetResult_Request__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_GetResult_Request__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci_GetResult_Request__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_GetResult_Request__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_GetResult_Request__TYPE_NAME, 53, 53},
      {example_interfaces__action__Fibonacci_GetResult_Request__FIELDS, 1, 1},
    },
    {example_interfaces__action__Fibonacci_GetResult_Request__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_GetResult_Response__FIELD_NAME__status[] = "status";
static char example_interfaces__action__Fibonacci_GetResult_Response__FIELD_NAME__result[] = "result";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_GetResult_Response__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_GetResult_Response__FIELD_NAME__status, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_INT8,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Response__FIELD_NAME__result, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_Result__TYPE_NAME, 42, 42},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci_GetResult_Response__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {example_interfaces__action__Fibonacci_Result__TYPE_NAME, 42, 42},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_GetResult_Response__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_GetResult_Response__TYPE_NAME, 54, 54},
      {example_interfaces__action__Fibonacci_GetResult_Response__FIELDS, 2, 2},
    },
    {example_interfaces__action__Fibonacci_GetResult_Response__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    description.referenced_type_descriptions.data[0].fields = example_interfaces__action__Fibonacci_Result__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_GetResult_Event__FIELD_NAME__info[] = "info";
static char example_interfaces__action__Fibonacci_GetResult_Event__FIELD_NAME__request[] = "request";
static char example_interfaces__action__Fibonacci_GetResult_Event__FIELD_NAME__response[] = "response";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_GetResult_Event__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_GetResult_Event__FIELD_NAME__info, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Event__FIELD_NAME__request, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {example_interfaces__action__Fibonacci_GetResult_Request__TYPE_NAME, 53, 53},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Event__FIELD_NAME__response, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {example_interfaces__action__Fibonacci_GetResult_Response__TYPE_NAME, 54, 54},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci_GetResult_Event__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Request__TYPE_NAME, 53, 53},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_GetResult_Response__TYPE_NAME, 54, 54},
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_Result__TYPE_NAME, 42, 42},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_GetResult_Event__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_GetResult_Event__TYPE_NAME, 51, 51},
      {example_interfaces__action__Fibonacci_GetResult_Event__FIELDS, 3, 3},
    },
    {example_interfaces__action__Fibonacci_GetResult_Event__REFERENCED_TYPE_DESCRIPTIONS, 6, 6},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = example_interfaces__action__Fibonacci_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = example_interfaces__action__Fibonacci_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = example_interfaces__action__Fibonacci_Result__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char example_interfaces__action__Fibonacci_FeedbackMessage__FIELD_NAME__goal_id[] = "goal_id";
static char example_interfaces__action__Fibonacci_FeedbackMessage__FIELD_NAME__feedback[] = "feedback";

static rosidl_runtime_c__type_description__Field example_interfaces__action__Fibonacci_FeedbackMessage__FIELDS[] = {
  {
    {example_interfaces__action__Fibonacci_FeedbackMessage__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {example_interfaces__action__Fibonacci_FeedbackMessage__FIELD_NAME__feedback, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {example_interfaces__action__Fibonacci_Feedback__TYPE_NAME, 44, 44},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription example_interfaces__action__Fibonacci_FeedbackMessage__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {example_interfaces__action__Fibonacci_Feedback__TYPE_NAME, 44, 44},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
example_interfaces__action__Fibonacci_FeedbackMessage__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {example_interfaces__action__Fibonacci_FeedbackMessage__TYPE_NAME, 51, 51},
      {example_interfaces__action__Fibonacci_FeedbackMessage__FIELDS, 2, 2},
    },
    {example_interfaces__action__Fibonacci_FeedbackMessage__REFERENCED_TYPE_DESCRIPTIONS, 2, 2},
  };
  if (!constructed) {
    description.referenced_type_descriptions.data[0].fields = example_interfaces__action__Fibonacci_Feedback__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}

static char toplevel_type_raw_source[] =
  "# Goal\n"
  "int32 order\n"
  "---\n"
  "# Result\n"
  "int32[] sequence\n"
  "---\n"
  "# Feedback\n"
  "int32[] sequence";

static char action_encoding[] = "action";
static char implicit_encoding[] = "implicit";

// Define all individual source functions

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci__get_individual_type_description_source(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci__TYPE_NAME, 35, 35},
    {action_encoding, 6, 6},
    {toplevel_type_raw_source, 81, 81},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_Goal__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_Goal__TYPE_NAME, 40, 40},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_Result__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_Result__TYPE_NAME, 42, 42},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_Feedback__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_Feedback__TYPE_NAME, 44, 44},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_SendGoal__get_individual_type_description_source(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_SendGoal__TYPE_NAME, 44, 44},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_SendGoal_Request__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_SendGoal_Request__TYPE_NAME, 52, 52},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_SendGoal_Response__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_SendGoal_Response__TYPE_NAME, 53, 53},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_SendGoal_Event__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_SendGoal_Event__TYPE_NAME, 50, 50},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_GetResult__get_individual_type_description_source(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_GetResult__TYPE_NAME, 45, 45},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_GetResult_Request__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_GetResult_Request__TYPE_NAME, 53, 53},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_GetResult_Response__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_GetResult_Response__TYPE_NAME, 54, 54},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_GetResult_Event__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_GetResult_Event__TYPE_NAME, 51, 51},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
example_interfaces__action__Fibonacci_FeedbackMessage__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {example_interfaces__action__Fibonacci_FeedbackMessage__TYPE_NAME, 51, 51},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci__get_type_description_sources(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[16];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 16, 16};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *example_interfaces__action__Fibonacci_Feedback__get_individual_type_description_source(NULL);
    sources[3] = *example_interfaces__action__Fibonacci_FeedbackMessage__get_individual_type_description_source(NULL);
    sources[4] = *example_interfaces__action__Fibonacci_GetResult__get_individual_type_description_source(NULL);
    sources[5] = *example_interfaces__action__Fibonacci_GetResult_Event__get_individual_type_description_source(NULL);
    sources[6] = *example_interfaces__action__Fibonacci_GetResult_Request__get_individual_type_description_source(NULL);
    sources[7] = *example_interfaces__action__Fibonacci_GetResult_Response__get_individual_type_description_source(NULL);
    sources[8] = *example_interfaces__action__Fibonacci_Goal__get_individual_type_description_source(NULL);
    sources[9] = *example_interfaces__action__Fibonacci_Result__get_individual_type_description_source(NULL);
    sources[10] = *example_interfaces__action__Fibonacci_SendGoal__get_individual_type_description_source(NULL);
    sources[11] = *example_interfaces__action__Fibonacci_SendGoal_Event__get_individual_type_description_source(NULL);
    sources[12] = *example_interfaces__action__Fibonacci_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[13] = *example_interfaces__action__Fibonacci_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[14] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[15] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_Goal__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[1];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 1, 1};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_Goal__get_individual_type_description_source(NULL),
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_Result__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[1];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 1, 1};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_Result__get_individual_type_description_source(NULL),
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_Feedback__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[1];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 1, 1};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_Feedback__get_individual_type_description_source(NULL),
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_SendGoal__get_type_description_sources(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[8];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 8, 8};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_SendGoal__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *example_interfaces__action__Fibonacci_Goal__get_individual_type_description_source(NULL);
    sources[3] = *example_interfaces__action__Fibonacci_SendGoal_Event__get_individual_type_description_source(NULL);
    sources[4] = *example_interfaces__action__Fibonacci_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[5] = *example_interfaces__action__Fibonacci_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[6] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[7] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_SendGoal_Request__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[3];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 3, 3};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_SendGoal_Request__get_individual_type_description_source(NULL),
    sources[1] = *example_interfaces__action__Fibonacci_Goal__get_individual_type_description_source(NULL);
    sources[2] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_SendGoal_Response__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_SendGoal_Response__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_SendGoal_Event__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[7];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 7, 7};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_SendGoal_Event__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *example_interfaces__action__Fibonacci_Goal__get_individual_type_description_source(NULL);
    sources[3] = *example_interfaces__action__Fibonacci_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[4] = *example_interfaces__action__Fibonacci_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[5] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[6] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_GetResult__get_type_description_sources(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[8];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 8, 8};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_GetResult__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *example_interfaces__action__Fibonacci_GetResult_Event__get_individual_type_description_source(NULL);
    sources[3] = *example_interfaces__action__Fibonacci_GetResult_Request__get_individual_type_description_source(NULL);
    sources[4] = *example_interfaces__action__Fibonacci_GetResult_Response__get_individual_type_description_source(NULL);
    sources[5] = *example_interfaces__action__Fibonacci_Result__get_individual_type_description_source(NULL);
    sources[6] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[7] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_GetResult_Request__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_GetResult_Request__get_individual_type_description_source(NULL),
    sources[1] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_GetResult_Response__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_GetResult_Response__get_individual_type_description_source(NULL),
    sources[1] = *example_interfaces__action__Fibonacci_Result__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_GetResult_Event__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[7];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 7, 7};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_GetResult_Event__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *example_interfaces__action__Fibonacci_GetResult_Request__get_individual_type_description_source(NULL);
    sources[3] = *example_interfaces__action__Fibonacci_GetResult_Response__get_individual_type_description_source(NULL);
    sources[4] = *example_interfaces__action__Fibonacci_Result__get_individual_type_description_source(NULL);
    sources[5] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[6] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
example_interfaces__action__Fibonacci_FeedbackMessage__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[3];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 3, 3};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *example_interfaces__action__Fibonacci_FeedbackMessage__get_individual_type_description_source(NULL),
    sources[1] = *example_interfaces__action__Fibonacci_Feedback__get_individual_type_description_source(NULL);
    sources[2] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}
